#!/bin/bash
# packager           : Markus Muttilainen <stillborn.zenwalk@gmail.com)
# source location    : http://download.savannah.gnu.org/releases/confuse/confuse-2.7.tar.gz
# last revised       : 22.10.2010

softname='confuse'
softversion='2.7'
packageversion='66.1'

arch='i486'
cpu='i686'

set -e -u -x

# log 
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
       |-----handy-ruler------------------------------------------------------|
confuse: confuse (a configuration file parser library)
confuse:
confuse: Licensed under the terms of the LGPL, and  written  in C. It  supports
confuse: sections  and  (lists of)  values (strings, integers, floats, booleans
confuse: or other sections), as  well as some  other  features (such as single/
confuse: double-quoted strings, environment  variable  expansion, functions and
confuse: nested include statements). It makes it very easy to add configuration
confuse: file capability to a program using a simple API.
confuse:                     
confuse:                             
confuse: 
EOF

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build

    export CFLAGS="-Wno-unused -O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-Wno-unused -O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=/usr \
      --enable-static=no \
      --enable-shared \
      --program-prefix="" \
      --program-suffix="" \
      --build=$arch-slackware-linux

    make || exit 1
    make install DESTDIR=$dest

# add 'default' files
    cp -a \
      AUTHORS INSTALL NEWS README \
      $dest/usr/doc/$softname-$softversion
      
# Strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Helperline
(cd $dest;find . -printf "%y %m %u:%g %p %l\n") > $buildir/pkgtree.log

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# md5sum signature
cd $buildir
md5sum $package.txz > $package.md5

# log 
) 2>&1 | tee "$softname-$softversion-build.log"
